pyngrok Coverage Report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
pyngrok/__init__.py | 0 | 0 | 0 | 100.00%
pyngrok/conf.py | 30 | 1 | 0 | 96.67%
pyngrok/exception.py | 28 | 0 | 0 | 100.00%
pyngrok/installer.py | 146 | 8 | 4 | 94.52%
pyngrok/ngrok.py | 219 | 28 | 6 | 87.21%
pyngrok/process.py | 209 | 8 | 15 | 96.17%
Total | 632 | 45 | 25 | 92.88%

No items found using the specified filter.